Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(570)

Unified Diff: net/url_request/url_request.h

Issue 7276: Adding security info to canceled requests (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: '' Created 11 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/url_request/url_request.h
===================================================================
--- net/url_request/url_request.h (revision 9948)
+++ net/url_request/url_request.h (working copy)
@@ -365,11 +365,16 @@
// no effect once the response has completed.
void Cancel();
- // Similar to Cancel but sets the error to |os_error| (see net_error_list.h
- // for values) instead of net::ERR_ABORTED.
- // Used to attach a reason for canceling a request.
- void CancelWithError(int os_error);
+ // Cancels the request and sets the error to |os_error| (see net_error_list.h
+ // for values).
+ void SimulateError(int os_error);
+ // Cancels the request and sets the error to |os_error| (see net_error_list.h
+ // for values) and attaches |ssl_info| as the SSLInfo for that request. This
+ // is useful to attach a certificate and certificate error to a canceled
+ // request.
+ void SimulateSSLError(int os_error, const net::SSLInfo& ssl_info);
+
// Read initiates an asynchronous read from the response, and must only
// be called after the OnResponseStarted callback is received with a
// successful status.
@@ -446,6 +451,10 @@
// been orphaned.
void OrphanJob();
+ // Cancels the request and set the error and ssl info for this request to the
+ // passed values.
+ void DoCancel(int os_error, const net::SSLInfo& ssl_info);
+
// Discard headers which have meaning in POST (Content-Length, Content-Type,
// Origin).
static std::string StripPostSpecificHeaders(const std::string& headers);

Powered by Google App Engine
This is Rietveld 408576698